==============
Optel Datalake
==============

A package for ingesting and transforming data in `Optel`_ 's Data Refinery.

Package source are shipped with distribution.

.. _pypi: https://test.pypi.org/project/optel.datalake/
.. _optel: https://www.optelpharmaceutical.com/
